chainalysis package - Data Solutions Python SDK 1.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# chainalysis package

## Subpackages

- chainalysis.orm package
  - Module contents
    - `Orm`
      - `Orm.TransactionalSelect()`
      - `Orm.AnalyticalSelect()`
    - `Select`
      - `Select.c`
      - `Select.table`
      - `Select.sql()`
      - `Select.execute()`
      - `Select.with_columns()`
      - `Select.where()`
      - `Select.select_from()`
      - `Select.limit()`
      - `Select.group_by()`
      - `Select.having()`
      - `Select.order_by()`
      - `Select.join()`
      - `Select.leftjoin()`
      - `Select.outerjoin()`
      - `Select.full_outerjoin()`
      - `Select.outerjoin_from()`
      - `Select.distinct()`
      - `Select.exists()`
      - `Select.alias()`
      - `Select.union()`
      - `Select.union_all()`
      - `Select.except_()`
      - `Select.except_all()`
      - `Select.intersect()`
      - `Select.intersect_all()`
      - `Select.lateral()`
    - `AnalyticalSelect`
      - `AnalyticalSelect.execute()`
    - `TransactionalSelect`
      - `TransactionalSelect.execute()`
    - `and_()`
    - `between()`
    - `case()`
    - `distinct()`
    - `except_()`
    - `except_all()`
    - `exists()`
    - `intersect()`
    - `intersect_all()`
    - `join()`
    - `leftjoin()`
    - `outerjoin()`
    - `full_outerjoin()`
    - `lateral()`
    - `literal()`
    - `not_()`
    - `or_()`
    - `union()`
    - `union_all()`
- chainalysis.sql package
  - Module contents
    - `Sql`
      - `Sql.transactional_query`
      - `Sql.analytical_query`
      - `Sql.transactional`
      - `Sql.analytical`
    - `AnalyticalQuery`
      - `AnalyticalQuery.__call__()`
      - `AnalyticalQuery.next_page()`
      - `AnalyticalQuery.json()`
      - `AnalyticalQuery.df()`
      - `AnalyticalQuery.stats()`
      - `AnalyticalQuery.status_code()`
      - `AnalyticalQuery.was_successful()`
      - `AnalyticalQuery.total_pages()`
      - `AnalyticalQuery.has_next()`
    - `TransactionalQuery`
      - `TransactionalQuery.__call__()`
      - `TransactionalQuery.json()`
      - `TransactionalQuery.df()`
      - `TransactionalQuery.stats()`
      - `TransactionalQuery.was_successful()`
      - `TransactionalQuery.status_code()`
- chainalysis.utils package
  - Module contents
    - `Utils`
      - `Utils.stringify`
    - `Stringify`
      - `Stringify.lists()`
      - `Stringify.columns()`
      - `Stringify.datetimes()`
      - `Stringify.dataframes()`

## Submodules

## chainalysis.data_solutions module

class chainalysis.data_solutions.DataSolutionsClient(api_key: str)

  Bases: `DataSolutionsClient`

  Warning

  This import path has been deprecated. Please use the following import path instead:

      from chainalysis import DataSolutionsClient

  This class provides SDK functions for users to query Data Solutions databases.

## Module contents

class chainalysis.DataSolutionsClient(api_key: str)

  Bases: `object`

  This class provides SDK functions for users to query Data Solutions databases.

  property sql: Sql

    Call the sql property to access the Sql class.

  property orm: Orm

    Call the orm property to access the Orm class.

  property utils: Utils

    Call the utils property to access the Utils class.